'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.build = undefined;

var _webfontsGenerator = require('webfonts-generator');

var _webfontsGenerator2 = _interopRequireDefault(_webfontsGenerator);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Responsible for the generation of the icon font
 * @param  {Object} config - an object containing all the needed options for the webfont generator.
 * @return {Object} a successful response or an error in case it occurs
 */
function build() {
  var config = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  return new Promise(function (resolve, reject) {
    try {
      if (config.customOpts && config.customOpts.help) {
        resolve('\nThese are all the available arguments:\n --out [String]: specifies where the generated code is stored into. Default "./build"\n --icons [String]: specifies the directory that contains the SVG icons for which you want to generate the font. Default "./icons"\n --baseclass [String]: specifies the base css class name. Default "dcs-icon"\n --classprefix [String]: specifies the css class prefix for all your icons. Default "dcs-icon-"\n --fontname [String]: the name for your brand new font. Default "dcsIconFont"\n --html: enables the generation of a html file with a preview for all the icons in the generated font\n          ');
        return;
      }

      var iconsPath = config.customOpts.icons || 'icons/*.svg';
      var files = _glob2.default.sync(iconsPath);

      if (!files.length) {
        throw new Error('Invalid file list');
      }

      if (config.customOpts.sass && config.customOpts.html) {
        throw new Error('Is not possible to generate a HTML preview for SASS outputs');
      }

      var options = Object.assign({}, config.webfontsOptions);
      options.files = files;

      generateDcsIconFont(options).then(function () {
        return resolve({ success: true });
      }).catch(function (e) {
        return reject(e);
      });
    } catch (e) {
      reject(e);
    }
  });
}

/**
 * Responsible for triggering the generation of the font
 * @param  {Object} webfontsOptions the options for the webfont generator
 * @return {Object} a promise with the result of the generation
 */
function generateDcsIconFont(webfontsOptions) {
  return new Promise(function (resolve, reject) {
    (0, _webfontsGenerator2.default)(webfontsOptions, function (error, result) {
      if (error) {
        reject(error);
      }

      // const urls = {
      //   eot: `${webfontsOptions.fontName}.eot`,
      //   woff: `${webfontsOptions.fontName}.woff`,
      //   ttf: `${webfontsOptions.fontName}.ttf`,
      //   svg: `${webfontsOptions.fontName}.svg`,
      // };
      //
      // console.log(result);
      // // console.log(result.generateCss(urls));

      resolve({ success: true, result: result });
    });
  });
}

exports.build = build;